---
meta:
    description:
        {{description
          |default(
          'A VPC, several public and private subnets, and security groups')}}

    parameters:
        vpc:
            description:
                Virtual Private Cloud
            value:
                cidr: 10.45.0.0/16
                name: {{_env.name}}-{{_env.stage}}

        enable_dns_hostnames:
            description:
                Specifies whether the instances launched in the VPC get DNS hostnames
            value:
                yes

        domain:
            description:
                A domain associated to the VPC.
            value:

        public_subnets:
            description:
                Public subnet(s)
            value:
                - cidr: 10.45.0.0/24
                  az: a

        private_subnets:
            description:
                Private subnet(s)
            value:
                # By default, no private subnets will be created
                []

        has_efs:
            description:
                Set to yes if the VPC should have an EFS
            value:
                no
